==> weather_es-6.x-1.11.tar.gz: weather_es/weather-es.tpl.php <==
<div class="weather_es">
  <p><strong><?php print t('Day: !day', array('!day' => $data->day)); ?></strong></p>
  <ul>
    <?php if ($data->sky_txt1 != '') :
      print '<li>'. $usrcnf->sky.' '. $data->ampm .' : <div style="text-align:center;"><img src="'. drupal_get_path(module, weather_es) .'/images/'. $data->sky_img1 .'.png" title="'. $data->sky_txt1 .'" alt="'. $data->sky_txt1 .'" width="64" height="64" /></div></li>';
    endif ?>
    <?php if ($data->sky_txt2 != '') :
      print '<li>'. $usrcnf->sky .' pm: <div style="text-align:center;"><img src="'. drupal_get_path(module, weather_es) .'/images/'. $data->sky_img2 .'.png" title="'. $data->sky_txt2 .'" alt="'. $data->sky_txt2 .'" width="64" height="64" /></div></li>';
    endif ?>
    <?php if ($data->rain != 999) :
      print '<li>'. $usrcnf->rain .': '. $data->rain .'</li>';
    endif ?>
    <?php if ($data->snow != '9999') :
      print '<li>'. $usrcnf->snow .': '. $data->snow .'</li>';
    endif ?>
    <?php if ($data->tmax != 99) :
      print '<li>'. $usrcnf->tmax .': '. $data->tmax .'</li>';
    endif ?>
    <?php if ($data->tmin != 99) :
      print '<li>'. $usrcnf->tmin .': '. $data->tmin .'</li>';
    endif ?>
    <?php if ($data->win_dir1 != '') :
      print '<li>'. $usrcnf->win_dir .' '. $data->ampm .': '. $data->win_dir1 .'</li>';
    endif ?>
    <?php if ($data->win_dir2 != '') :
      print '<li>'. $usrcnf->win_dir .' pm: '. $data->win_dir2 .'</li>';
    endif ?>
    <?php if ($data->win_spd1 != 999) :
      print '<li>'. $usrcnf->win_spd .' '. $data->ampm .': '. $data->win_spd1 .'</li>';
    endif ?>
    <?php if ($data->win_spd2 != 999) :
      print '<li>'. $usrcnf->win_spd .' pm: '. $data->win_spd2 .'</li>';
    endif ?>
    <?php if ($data->iv_max != 99) :
      print '<li>'. $usrcnf->iv .': '. $data->iv_max .'</li>';
    endif ?>
    <?php if ($data->rsk != '') :
      print '<li>'. $usrcnf->rsk .': '. $data->rsk .'</li>';
    endif ?>
  </ul>
</div>

==> weather_es-6.x-2.3.tar.gz: weather_es/weather-es.tpl.php <==
<div class="weather_es">
  <p><strong><?php print t('Day: !day', array('!day' => $data->day)); ?></strong></p>
  <ul>
    <?php if ($data->sky_txt1 != '') :
      print '<li>'. $usrcnf->sky.' '. $data->ampm .' : <div style="text-align:center;"><img src="'. drupal_get_path(module, weather_es) .'/images/'. $data->sky_img1 .'.png" title="'. $data->sky_txt1 .'" alt="'. $data->sky_txt1 .'" width="64" height="64" /></div></li>';
    endif ?>
    <?php if ($data->sky_txt2 != '') :
      print '<li>'. $usrcnf->sky .' pm: <div style="text-align:center;"><img src="'. drupal_get_path(module, weather_es) .'/images/'. $data->sky_img2 .'.png" title="'. $data->sky_txt2 .'" alt="'. $data->sky_txt2 .'" width="64" height="64" /></div></li>';
    endif ?>
    <?php if ($data->rain != 999) :
      print '<li>'. $usrcnf->rain .': '. $data->rain .'%</li>';
    endif ?>
    <?php if ($data->snow != '9999') :
      print '<li>'. $usrcnf->snow .': '. $data->snow .'</li>';
    endif ?>
    <?php if ($data->tmax != 99) :
      print '<li>'. $usrcnf->tmax .': '. $data->tmax .'</li>';
    endif ?>
    <?php if ($data->tmin != 99) :
      print '<li>'. $usrcnf->tmin .': '. $data->tmin .'</li>';
    endif ?>
    <?php if ($data->win_dir1 != '') :
      print '<li>'. $usrcnf->win_dir .' '. $data->ampm .': '. $data->win_dir1 .'</li>';
    endif ?>
    <?php if ($data->win_dir2 != '') :
      print '<li>'. $usrcnf->win_dir .' pm: '. $data->win_dir2 .'</li>';
    endif ?>
    <?php if ($data->win_spd1 != 999) :
      print '<li>'. $usrcnf->win_spd .' '. $data->ampm .': '. $data->win_spd1 .'</li>';
    endif ?>
    <?php if ($data->win_spd2 != 999) :
      print '<li>'. $usrcnf->win_spd .' pm: '. $data->win_spd2 .'</li>';
    endif ?>
    <?php if ($data->iv_max != 99) :
      print '<li>'. $usrcnf->iv .': '. $data->iv_max .'</li>';
    endif ?>
    <?php if ($data->rsk != '') :
      print '<li>'. $usrcnf->rsk .': '. $data->rsk .'</li>';
    endif ?>
  </ul>
</div>
